@@ -479,13 +479,17 @@ sub cut
 
 =head1 AUTHOR
 
-Martin Hosken L<http://scripts.sil.org/FontUtils>. 
+Martin Hosken L<Martin_Hosken@sil.org>. 
 
 =head1 LICENSING
 
-Copyright (c) 1998-2014, SIL International (http://www.sil.org)
+Copyright (c) 1998-2013, SIL International (http://www.sil.org)
 
-This module is released under the terms of the Artistic License 2.0.
-For details, see the full text of the license in the file LICENSE.
+This module and all the various scripts are released under the terms of the
+Artistic License 2.0. For details, see the full text of the license in the file
+LICENSE.
 
-=cut
\ No newline at end of file
+The test suite contains test fonts released under the Open Font License v1.1, see OFL.txt.
+
+
+=cut
